@@ -56,8 +56,8 @@
 
 /* Maximum zoom factor */
 
-#define MAX_ZOOM_FACTOR 20
-#define MIN_ZOOM_FACTOR 0.01
+#define MAX_ZOOM_FACTOR 10
+#define MIN_ZOOM_FACTOR 0.05
 
 /* Private part of the ImageView structure */
 struct _ImageViewPrivate {
@@ -67,6 +67,9 @@ struct _ImageViewPrivate {
 	/* Current zoom factors */
 	double zoomx;
 	double zoomy;
+	
+	/* Minimum Zoom Factor for This Pixbuf */
+	double MIN_ZOOM;
 
 	/* Previous zoom factor and zoom anchor point stored for size_allocate */
 	double old_zoomx;
@@ -112,6 +115,8 @@ struct _ImageViewPrivate {
 
 	/* Whether we need to change the zoom factor */
 	guint need_zoom_change : 1;
+	
+	guint enable_late_drawing : 1;
 
 #ifdef LIBEOG_ETTORE_CHANGES
 	float display_brightness;
@@ -260,6 +265,7 @@ image_view_instance_init (ImageView *view)
 	priv->use_check_pattern = TRUE;
 	priv->transparency_color = CHECK_BLACK;
 
+	priv->enable_late_drawing = FALSE;
 #ifdef LIBEOG_ETTORE_CHANGES
 	priv->display_brightness = 0.0;
 	priv->display_contrast = 0.0;
@@ -552,6 +558,26 @@ apply_transform_to_pixbuf (ImageView *view, GdkPixbuf *pixbuf, int x, int y, int
 #endif
 
 /* Paints a rectangle of the dirty region */
+#ifdef LIBEOG_ETTORE_CHANGES
+static void
+paint_extra (ImageView *view,
+	     ArtIRect *rect)
+{
+	ImageViewClass *class = G_TYPE_INSTANCE_GET_CLASS (view, TYPE_IMAGE_VIEW, ImageViewClass);
+	GdkRectangle area;
+
+	g_assert (rect->x0 < rect->x1);
+	g_assert (rect->y0 < rect->y1);
+
+	area.x = rect->x0;
+	area.y = rect->y0;
+
+	area.width = rect->x1 - rect->x0;
+	area.height = rect->y1 - rect->y0;
+
+	(* class->paint_extra) (view, &area);
+}
+#endif
 
 #ifdef LIBEOG_ETTORE_CHANGES
 static void
@@ -756,7 +782,7 @@ paint_rectangle (ImageView *view, ArtIRect *rect, GdkInterpType interp_type)
 				    d.x1 - d.x0, d.y1 - d.y0,
 				    -(d.x0 - xofs), -(d.y0 - yofs),
 				    priv->zoomx, priv->zoomy,
-				    unity_zoom (priv) ? GDK_INTERP_NEAREST : interp_type,
+				    ABS (d.x1 - d.x0) < 20 || ABS (d.y1 - d.y0) < 20 || unity_zoom (priv) ? GDK_INTERP_NEAREST : interp_type,
 				    255,
 				    d.x0 - xofs, d.y0 - yofs,
 				    check_size,
@@ -794,18 +820,30 @@ paint_rectangle (ImageView *view, ArtIRect *rect, GdkInterpType interp_type)
 				      gdk_pixbuf_get_rowstride (tmp),
 				      d.x0 - xofs, d.y0 - yofs);
 #else
-	if (gdk_pixbuf_get_has_alpha (priv->pixbuf))
+	/*
+	  if (gdk_pixbuf_get_has_alpha (priv->pixbuf))
 		paint_background (view, &d, rect);
 
-	gdk_pixbuf_render_to_drawable_alpha (tmp,
-					     GTK_WIDGET (view)->window,
-					     0, 0,
-					     d.x0, d.y0,
-					     d.x1 - d.x0, d.y1 - d.y0,
-					     priv->dither,
-					     GDK_PIXBUF_ALPHA_FULL,
-					     0,
-					     d.x0 - xofs, d.y0 - yofs);
+	  gdk_pixbuf_render_to_drawable_alpha (tmp,
+		GTK_WIDGET (view)->window,
+		0, 0,
+		d.x0, d.y0,
+		d.x1 - d.x0, d.y1 - d.y0,
+		priv->dither,
+		GDK_PIXBUF_ALPHA_FULL,
+		0,
+		d.x0 - xofs, d.y0 - yofs);
+	*/
+
+	gdk_pixbuf_render_to_drawable (tmp,
+				       GTK_WIDGET (view)->window,
+				       GTK_WIDGET (view)->style->black_gc,
+				       0, 0,
+				       d.x0, d.y0,
+				       d.x1 - d.x0, d.y1 - d.y0,
+				       priv->dither,
+				       d.x0 - xofs, d.y0 - yofs);
+	
 #endif
 
 	g_object_unref (tmp);
@@ -820,29 +858,9 @@ paint_rectangle (ImageView *view, ArtIRect *rect, GdkInterpType interp_type)
 		       d.x1 - 1, d.y0,
 		       d.x0, d.y1 - 1);
 #endif
+	paint_extra (view, &r);
 }
 
-#ifdef LIBEOG_ETTORE_CHANGES
-static void
-paint_extra (ImageView *view,
-	     ArtIRect *rect)
-{
-	ImageViewClass *class = G_TYPE_INSTANCE_GET_CLASS (view, TYPE_IMAGE_VIEW, ImageViewClass);
-	GdkRectangle area;
-
-	g_assert (rect->x0 < rect->x1);
-	g_assert (rect->y0 < rect->y1);
-
-	area.x = rect->x0;
-	area.y = rect->y0;
-
-	area.width = rect->x1 - rect->x0;
-	area.height = rect->y1 - rect->y0;
-
-	(* class->paint_extra) (view, &area);
-}
-#endif
-
 #include <stdio.h>
 
 /* Idle handler for the drawing process.  We pull a rectangle from the dirty
@@ -869,7 +887,6 @@ paint_iteration_idle (gpointer data)
 	} else {
 #ifdef LIBEOG_ETTORE_CHANGES
 		paint_rectangle (view, &rect, priv->interp_type, TRUE);
-		paint_extra (view, &rect);
 #else
 		paint_rectangle (view, &rect, priv->interp_type);
 #endif
@@ -908,10 +925,9 @@ request_paint_area (ImageView *view, GdkRectangle *area)
 
 	/* Do nearest neighbor or 1:1 zoom synchronously for speed.  */
 
-	if (priv->interp_type == GDK_INTERP_NEAREST || unity_zoom (priv)) {
+	if (!priv->enable_late_drawing || priv->interp_type == GDK_INTERP_NEAREST || unity_zoom (priv)) {
 #ifdef LIBEOG_ETTORE_CHANGES
 		paint_rectangle (view, &r, priv->interp_type, TRUE);
-		paint_extra (view, &r);
 #else
 		paint_rectangle (view, &r, priv->interp_type);
 #endif
@@ -929,7 +945,6 @@ request_paint_area (ImageView *view, GdkRectangle *area)
 
 #ifdef LIBEOG_ETTORE_CHANGES
 	paint_rectangle (view, &r, GDK_INTERP_NEAREST, FALSE);
-	paint_extra (view, &r);
 #else
 	paint_rectangle (view, &r, GDK_INTERP_NEAREST);
 #endif
@@ -1404,14 +1419,15 @@ image_view_scroll_event (GtkWidget *widget, GdkEventScroll *event)
 {
 	ImageView *view;
 	ImageViewPrivate *priv;
-	double zoom_factor;
-	int xofs, yofs;
 
 	view = IMAGE_VIEW (widget);
 	priv = view->priv;
-
+	
 	/* Compute zoom factor and scrolling offsets; we'll only use either of them */
 
+	double zoom_factor;
+	int xofs, yofs;
+
 	xofs = priv->hadj->page_increment / 2; /* same as in gtkscrolledwindow.c */
 	yofs = priv->vadj->page_increment / 2;
 
@@ -1792,15 +1808,17 @@ image_view_set_zoom (ImageView *view, double zoomx, double zoomy,
 	g_return_if_fail (zoomy > 0.0);
 
 	priv = view->priv;
+		
+	image_view_update_min_zoom (view);
 
 	if (zoomx > MAX_ZOOM_FACTOR)
 		zoomx = MAX_ZOOM_FACTOR;
-	else if (zoomx < MIN_ZOOM_FACTOR)
-		zoomx = MIN_ZOOM_FACTOR;
+	else if (zoomx < priv->MIN_ZOOM)
+		zoomx = priv->MIN_ZOOM;
 	if (zoomy > MAX_ZOOM_FACTOR)
 		zoomy = MAX_ZOOM_FACTOR;
-	else if (zoomy < MIN_ZOOM_FACTOR)
-		zoomy = MIN_ZOOM_FACTOR;
+	else if (zoomy < priv->MIN_ZOOM)
+		zoomy = priv->MIN_ZOOM;
 
 	if (DOUBLE_EQUAL (priv->zoomx, zoomx) &&
 	    DOUBLE_EQUAL (priv->zoomy, zoomy))
@@ -2184,6 +2202,25 @@ image_view_class_init (ImageViewClass *class)
 	widget_class->focus_out_event = image_view_focus_out_event;
 }
 
+void
+image_view_update_min_zoom (ImageView *view)
+{
+	ImageViewPrivate *priv = view->priv;
+
+	priv->MIN_ZOOM = MIN_ZOOM_FACTOR;
+	if (priv->pixbuf) {
+		double width = (double) gdk_pixbuf_get_width (priv->pixbuf);
+		double height = (double) gdk_pixbuf_get_height (priv->pixbuf);
+
+		priv->MIN_ZOOM = ((double) GTK_WIDGET (view)->allocation.width)/ width;
+
+		if (((double) GTK_WIDGET (view)->allocation.height) / height < priv->MIN_ZOOM)
+			priv->MIN_ZOOM = ((double) GTK_WIDGET (view)->allocation.height)/ height;
+
+		if (priv->MIN_ZOOM > 1.0)
+			priv->MIN_ZOOM = 1.0;
+	}
+}
 
 #ifdef LIBEOG_ETTORE_CHANGES
 
@@ -2253,4 +2290,10 @@ image_view_set_display_transform (ImageView *view, cmsHTRANSFORM transform)
 	view->priv->transform = transform;
 }
 
+void
+image_view_set_delay_scaling (ImageView *view, gboolean enable)
+{
+	view->priv->enable_late_drawing = enable;
+}
+
 #endif
