@@ -466,7 +466,7 @@ get_drag_mode_for_mouse_position (FImageView *view,
 				  int *drag_x_offset_return, int *drag_y_offset_return)
 {
 	FImageViewPrivate *priv = view->priv;
-	int x1, y1, x2, y2;
+	int x1, y1, x2, y2, swap;
 
 	if (! priv->selection_active)
 		return MODE_IDLE;
@@ -474,6 +474,18 @@ get_drag_mode_for_mouse_position (FImageView *view,
 	image_coords_to_window (view, priv->selection.x1, priv->selection.y1, &x1, &y1);
 	image_coords_to_window (view, priv->selection.x2, priv->selection.y2, &x2, &y2);
 
+	//Swap coords so x1<x2 and y1<y2
+	if (priv->selection.x1 > priv->selection.x2) {
+		swap = priv->selection.x1 ;
+		priv->selection.x1 = priv->selection.x2 ;
+		priv->selection.x2 = swap ;
+	}
+	if (priv->selection.y1 > priv->selection.y2) {
+		swap = priv->selection.y1 ;
+		priv->selection.y1 = priv->selection.y2 ;
+		priv->selection.y2 = swap ;
+	}
+
 	if (check_corner_for_drag (x1, y1, mouse_x, mouse_y,
 				   drag_x_offset_return, drag_y_offset_return))
 		return MODE_DRAG_X1Y1;
@@ -529,10 +541,11 @@ emit_selection_changed (FImageView *image_view)
 /* ImageView methods.  */
 
 static void
-impl_paint_extra (FImageView *image_view,
+impl_paint_extra (ImageView *iv,
 		  GdkRectangle *area)
 {
 #if FALSE
+	FImageView *image_view = (FImageView *) iv;
 	FImageViewPrivate *priv = image_view->priv;
 	int x1, y1, x2, y2;
 	cairo_t *ctx;
