@@ -2,8 +2,10 @@ using Gdk;
 using Gtk;
 using Gnome;
 using System.Collections;
+using System.Collections.Generic;
 using System;
 using FSpot;
+using FSpot.Utils;
 using FSpot.Xmp;
 using FSpot.UI.Dialog;
 using System.IO;
@@ -48,7 +50,7 @@ public class FileImportBackend : ImportBackend {
 		public ImportInfo (string original)
 		{
 			original_path = original;
-		        destination_path= null;
+		        destination_path = null;
 			Photo = null;
 		}
 	}
@@ -73,22 +75,16 @@ public class FileImportBackend : ImportBackend {
 	private void GetListing (System.IO.DirectoryInfo dirinfo, System.IO.FileInfo [] files, bool recurse)
 	{
 		System.Console.WriteLine ("Scanning {0}", dirinfo.FullName);
-		Hashtable exiting_entries = new Hashtable ();
+		List<Uri> existing_entries = new List<Uri> ();
 
 		foreach (Photo p in store.Query (dirinfo)) {
 			foreach (uint id in p.VersionIds) {
-				string name;
-				if (id == Photo.OriginalVersionId)
-				        name = p.Name;
-				else 
-					name = (new System.IO.FileInfo (p.VersionUri (id).LocalPath)).Name;
-
-				exiting_entries [name] = p;
+				existing_entries.Add (p.VersionUri (id));
 			}
 		}
-	
+
 		foreach (System.IO.FileInfo f in files) {
-			if (! exiting_entries.Contains (f.Name)) {
+			if (! existing_entries.Contains (UriUtils.PathToFileUri (f.FullName)) && !f.Name.StartsWith (".")) {
 				AddPath (f.FullName);
 			}
 		}
