@@ -11,7 +11,6 @@ using System;
 using Gtk;
 using Gdk;
 using FSpot.Widgets;
-using Cairo;
 using Mono.Unix;
 
 namespace FSpot {
@@ -32,8 +31,15 @@ namespace FSpot {
 		const string SlideShow = "SlideShow";
 		const string Info = "Info";
 		
-		public FullScreenView (IBrowsableCollection collection) : base ("Full Screen Mode")
+		public FullScreenView (IBrowsableCollection collection, Gtk.Window parent) : base ("Full Screen Mode")
 		{
+			//going fullscreen on the same screen the parent window
+			Gdk.Screen screen = Screen;
+			int monitor = screen.GetMonitorAtWindow (parent.GdkWindow);
+			Gdk.Rectangle bounds = screen.GetMonitorGeometry(monitor);
+			Move(bounds.X, 0);
+
+
 			string style = "style \"test\" {\n" +
 				"GtkToolbar::shadow_type = GTK_SHADOW_NONE\n" +
 				"}\n" +
@@ -215,7 +221,7 @@ namespace FSpot {
 		protected override bool OnExposeEvent (Gdk.EventExpose args)
 		{
 			bool ret = base.OnExposeEvent (args);
-			Graphics g = CairoUtils.CreateDrawable (GdkWindow);
+			Graphics g = CairoHelper.Create (GdkWindow);
 
 			g.Color = new Cairo.Color (0, 0, 0, .5);
 			g.Operator = Operator.DestOut;
