@@ -151,6 +151,7 @@ namespace FSpot {
 			}
 		}
 
+		[Obsolete ("use HasLoader (System.Uri) instead")]
 		public static bool HasLoader (string path)
 		{
 			return HasLoader (UriUtils.PathToFileUri (path));
@@ -165,6 +166,7 @@ namespace FSpot {
 			return (t != null);
 		}
 
+		[Obsolete ("use Create (System.Uri) instead")]
 		public static ImageFile Create (string path)
 		{
 			return Create (UriUtils.PathToFileUri (path));
@@ -216,7 +218,16 @@ namespace FSpot {
 
 		public static bool IsRaw (string name)
 		{
-			string [] raw_extensions = {".nef", ".crw", ".cr2", ".arw", ".mrw", ".pef", ".dng"};
+			string [] raw_extensions = {
+				".arw",
+				".crw",
+				".cr2",
+				".dng",
+				".mrw",
+				".nef",
+				".pef", 
+				".raw",
+			};
 			foreach (string ext in raw_extensions)
 				if (ext == System.IO.Path.GetExtension (name).ToLower ())
 					return true;
