@@ -1,3 +1,16 @@
+/*
+ * ImportCommand.cs
+ *
+ * Author(s)
+ * 	Ettore Perazzoli
+ * 	Larry Ewing
+ * 	Miguel de Icaza
+ * 	Nat Friedman
+ * 	Gabriel Burt
+ *
+ * This is free software. See COPYING for details.
+ */
+
 using GLib;
 using Gdk;
 using Gnome;
@@ -8,8 +21,15 @@ using System.IO;
 using System;
 using Mono.Unix;
 
-public class ImportCommand : FSpot.GladeDialog {
-	internal class SourceItem : ImageMenuItem {
+using FSpot.Widgets;
+using FSpot;
+using FSpot.Utils;
+using FSpot.UI.Dialog;
+
+public class ImportCommand : FSpot.GladeDialog
+{
+	internal class SourceItem : ImageMenuItem
+	{
 		public ImportSource Source;
 
 		public SourceItem (ImportSource source) : base (source.Name.Replace ("_", "__"))
@@ -22,33 +42,35 @@ public class ImportCommand : FSpot.GladeDialog {
 		}
 	} 
 
-	internal class BrowseSource : ImportSource {
+	internal class BrowseSource : ImportSource
+	{
 		public BrowseSource ()
 		{
 			this.Name = Catalog.GetString ("Select Folder");
-			this.Icon = PixbufUtils.LoadThemeIcon ("stock_folder", 32);
+			this.Icon = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, "stock_folder", 32, (Gtk.IconLookupFlags)0);
 		}
 
 		public BrowseSource (string name, string icon)
 		{
 			this.Name = name;
-			this.Icon = PixbufUtils.LoadThemeIcon (icon, 32);
+			this.Icon = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, icon, 32, (Gtk.IconLookupFlags)0);
 		}
 	}
 
-	internal class VfsSource : ImportSource {
+	internal class VfsSource : ImportSource
+	{
 		public string uri;
 
 		public VfsSource (string uri)
 		{ 
 			string [] components = uri.Split (new char [] { '/' });
 			this.Name = components [components.Length - 1];
-			if (this.Name == "")
+			if (this.Name == String.Empty)
 				this.Name = components [components.Length - 2];
 
 			this.uri = uri;
 			
-			this.Icon = PixbufUtils.LoadThemeIcon ("stock_folder", 32);
+			this.Icon = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, "stock_folder", 32, (Gtk.IconLookupFlags)0);
 		}
 
 		public virtual bool Contains (string path)
@@ -59,7 +81,8 @@ public class ImportCommand : FSpot.GladeDialog {
 		protected VfsSource () {}
 	}
 
-	internal class VolumeSource : VfsSource {
+	internal class VolumeSource : VfsSource
+	{
 		public Gnome.Vfs.Volume Volume;
 		public string mount_point;
 
@@ -77,13 +100,13 @@ public class ImportCommand : FSpot.GladeDialog {
 			uri = mount_point;
 			
                         if (this.Icon == null)
-				this.Icon = PixbufUtils.LoadThemeIcon (vol.Icon, 32);
+				this.Icon = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, vol.Icon, 32, (Gtk.IconLookupFlags)0);
 			
 			if (this.IsIPodPhoto)
-				this.Icon = PixbufUtils.LoadThemeIcon ("gnome-dev-ipod", 32);
+				this.Icon = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, "multimedia-player", 32, (Gtk.IconLookupFlags)0);
 
 			if (this.Icon == null && this.IsCamera)
-				this.Icon = PixbufUtils.LoadThemeIcon ("gnome-dev-media-cf", 32);
+				this.Icon = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, "media-flash", 32, (Gtk.IconLookupFlags)0);
 
 			try {
 				if (this.Icon == null)
@@ -119,7 +142,8 @@ public class ImportCommand : FSpot.GladeDialog {
 		}
 	}
 
-	internal class DriveSource : ImportSource {
+	internal class DriveSource : ImportSource
+	{
 		public Gnome.Vfs.Drive Drive;
 		
 		public DriveSource (Gnome.Vfs.Drive drive) 
@@ -128,15 +152,16 @@ public class ImportCommand : FSpot.GladeDialog {
 			this.Drive = drive;
 
 			if (drive.IsMounted) {
-				this.Icon = PixbufUtils.LoadThemeIcon (drive.MountedVolume.Icon, 32);
+				this.Icon = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, drive.MountedVolume.Icon, 32, (Gtk.IconLookupFlags)0);
 				//this.Sensitive = drive.MountedVolume.IsMounted;
 			} else {
-				this.Icon = PixbufUtils.LoadThemeIcon (drive.Icon, 32);
+				this.Icon = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, drive.Icon, 32, (Gtk.IconLookupFlags)0);
 			}
 		}
 	}
 
-	internal class CameraSource : ImportSource {
+	internal class CameraSource : ImportSource
+	{
 		GPhotoCamera cam;
 		int CameraIndex;
 		
@@ -150,9 +175,9 @@ public class ImportCommand : FSpot.GladeDialog {
 #else
 			this.Name = String.Format ("{0}", cam.CameraList.GetName (index));
 #endif
-			this.Icon = PixbufUtils.LoadThemeIcon ("gnome-dev-camera", 32);
+			this.Icon = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, "camera-photo", 32, (Gtk.IconLookupFlags)0);
 			if (this.Icon == null)
-				this.Icon = PixbufUtils.LoadThemeIcon ("gnome-dev-media-cf", 32);
+				this.Icon = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, "media-flash", 32, (Gtk.IconLookupFlags)0);
 		}
 
 		public string Port {
@@ -168,7 +193,8 @@ public class ImportCommand : FSpot.GladeDialog {
 		public string Name;
 	}
 	
-	private class SourceMenu : Gtk.Menu {
+	private class SourceMenu : Gtk.Menu
+	{
 		public int source_count;
 		ImportCommand command;
 
@@ -291,11 +317,10 @@ public class ImportCommand : FSpot.GladeDialog {
 		}
 	}		
 	
-	[Glade.Widget] Gtk.OptionMenu tag_option_menu;
+	[Glade.Widget] Gtk.HBox tagentry_box;
 	[Glade.Widget] Gtk.OptionMenu source_option_menu;
 	[Glade.Widget] Gtk.ScrolledWindow icon_scrolled;
 	[Glade.Widget] Gtk.ScrolledWindow photo_scrolled;
-	[Glade.Widget] Gtk.CheckButton attach_check;
 	[Glade.Widget] Gtk.CheckButton recurse_check;
 	[Glade.Widget] Gtk.CheckButton copy_check;
 	[Glade.Widget] Gtk.Button ok_button;
@@ -303,8 +328,11 @@ public class ImportCommand : FSpot.GladeDialog {
 	[Glade.Widget] Gtk.Label tag_label;
 	[Glade.Widget] Gtk.EventBox frame_eventbox;
 	[Glade.Widget] ProgressBar progress_bar;
+	[Glade.Widget] Gtk.HPaned import_hpaned;
 	
-	Tag tag_selected;
+	ArrayList tags_selected;
+
+	FSpot.Widgets.TagEntry tag_entry;
 
 	Gtk.Window main_window;
 	FSpot.PhotoList collection;
@@ -317,7 +345,7 @@ public class ImportCommand : FSpot.GladeDialog {
 	
 	FSpot.PhotoImageView photo_view;
 	ImportBackend importer;
-	IconView tray;
+	FSpot.Widgets.IconView tray;
 
 	FSpot.Delay idle_start; 
 
@@ -429,8 +457,11 @@ public class ImportCommand : FSpot.GladeDialog {
 		
 			//grid.AddThumbnail (thumbnail);
 
-			thumbnail.Dispose ();
 		}
+
+		if (thumbnail != null)
+			thumbnail.Dispose ();
+		
 		if (count < total)
 			UpdateProgressBar (count + 1, total);
 
@@ -496,11 +527,6 @@ public class ImportCommand : FSpot.GladeDialog {
 		importer = null;
 	}
 	
-	public void HandleTagToggled (object o, EventArgs args) 
-	{
-		tag_option_menu.Sensitive = attach_check.Active;
-	}
-
 	public void HandleImportBrowse (object o, EventArgs args) 
 	{
 		string path = ChoosePath ();
@@ -539,12 +565,12 @@ public class ImportCommand : FSpot.GladeDialog {
 		import_path = path;
 	}
 
-	private void HandleTagMenuSelected (Tag t) 
-	{
-		tag_selected = t;
-		//tag_image.Pixbuf = t.Icon;
-		//tag_label.Text = t.Name;
-	}
+//	private void HandleTagMenuSelected (Tag t) 
+//	{
+//		tag_selected = t;
+//		//tag_image.Pixbuf = t.Icon;
+//		//tag_label.Text = t.Name;
+//	}
 
 	private void HandleRecurseToggled (object sender, System.EventArgs args)
 	{
@@ -563,8 +589,12 @@ public class ImportCommand : FSpot.GladeDialog {
 		this.Dialog.WindowPosition = Gtk.WindowPosition.CenterOnParent;
 		this.Dialog.Response += HandleDialogResponse;
 
-		CreateTagMenu ();
-		
+ 		if ((int) FSpot.Preferences.Get (FSpot.Preferences.IMPORT_WINDOW_WIDTH) > 0)
+ 			this.Dialog.Resize ((int) FSpot.Preferences.Get (FSpot.Preferences.IMPORT_WINDOW_WIDTH), (int) FSpot.Preferences.Get(FSpot.Preferences.IMPORT_WINDOW_HEIGHT));
+
+ 		if ((int) FSpot.Preferences.Get (FSpot.Preferences.IMPORT_WINDOW_PANE_POSITION) > 0)
+			import_hpaned.Position = (int) FSpot.Preferences.Get (FSpot.Preferences.IMPORT_WINDOW_PANE_POSITION);
+
 	        AllowFinish = false;
 		
 		this.Dialog.DefaultResponse = ResponseType.Ok;
@@ -577,9 +607,9 @@ public class ImportCommand : FSpot.GladeDialog {
 		source_option_menu.Menu = menu;
 
 		collection = new FSpot.PhotoList (new Photo [0]);
-		tray = new FSpot.ScalingIconView (collection);
+		tray = new ScalingIconView (collection);
 		tray.Selection.Changed += HandleTraySelectionChanged;
-		icon_scrolled.SetSizeRequest (200, 200);
+		icon_scrolled.SetSizeRequest (400, 200);
 		icon_scrolled.Add (tray);
 		//icon_scrolled.Visible = false;
 		tray.DisplayTags = false;
@@ -590,20 +620,21 @@ public class ImportCommand : FSpot.GladeDialog {
 		photo_scrolled.SetSizeRequest (200, 200);
 		photo_view.Show ();
 
-		//FSpot.Global.ModifyColors (frame_eventbox);
-		FSpot.Global.ModifyColors (photo_scrolled);
-		FSpot.Global.ModifyColors (photo_view);
+		//GtkUtil.ModifyColors (frame_eventbox);
+		GtkUtil.ModifyColors (photo_scrolled);
+		GtkUtil.ModifyColors (photo_view);
 
-		photo_view.Pixbuf = PixbufUtils.LoadFromAssembly ("f-spot-logo.png");
+		photo_view.Pixbuf = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, "f-spot", 48, (Gtk.IconLookupFlags)0);
 		photo_view.Fit = true;
 			
-		tag_selected = null;
-		if (attach_check != null) {
-			attach_check.Toggled += HandleTagToggled;
-			HandleTagToggled (null, null);
-		}				
+		tag_entry = new FSpot.Widgets.TagEntry (MainWindow.Toplevel.Database.Tags, false);
+		tag_entry.UpdateFromTagNames (new string []{});
+		tagentry_box.Add (tag_entry);
+
+		tag_entry.Show ();
 
 		this.Dialog.Show ();
+
 		//source_option_menu.Changed += HandleSourceChanged;
 		if (path != null) {
 			SetImportPath (path);
@@ -647,20 +678,28 @@ public class ImportCommand : FSpot.GladeDialog {
 		}
 
 		if (response == ResponseType.Ok) {
+			this.UpdateTagStore (tag_entry.GetTypedTagNames ());
 			this.Finish ();
 
-			if (attach_check.Active && tag_selected != null) {
+			if (tags_selected != null && tags_selected.Count > 0) {
 				for (int i = 0; i < collection.Count; i++) {
 					Photo p = collection [i] as Photo;
 					
 					if (p == null)
 						continue;
 					
-					p.AddTag (tag_selected);
+					p.AddTag ((Tag [])tags_selected.ToArray(typeof(Tag)));
 					store.Commit (p);
 				}
 			}
 
+			int width, height;
+			this.Dialog.GetSize (out width, out height);
+
+			FSpot.Preferences.Set (FSpot.Preferences.IMPORT_WINDOW_WIDTH, width);
+			FSpot.Preferences.Set (FSpot.Preferences.IMPORT_WINDOW_HEIGHT, height);
+			FSpot.Preferences.Set (FSpot.Preferences.IMPORT_WINDOW_PANE_POSITION, import_hpaned.Position);
+
 			this.Dialog.Destroy ();
 			return collection.Count;
 		} else {
@@ -670,30 +709,34 @@ public class ImportCommand : FSpot.GladeDialog {
 		}
 	}
 
-	private void CreateTagMenu ()
+	private void UpdateTagStore (string [] new_tags)
 	{
-		TagMenu tagmenu = new TagMenu (null, MainWindow.Toplevel.Database.Tags);
-		tagmenu.NewTagHandler = HandleNewTagSelected;
+		if (new_tags == null || new_tags.Length == 0)
+			return;
 
-		tagmenu.Append (new MenuItem (Catalog.GetString ("Select Tag")));
-		
-		tagmenu.Populate (true);
-		
-		tagmenu.TagSelected += HandleTagMenuSelected;
-		
-		tagmenu.ShowAll ();
-		tag_option_menu.Menu = tagmenu;
-	}
+		tags_selected = new ArrayList ();
+		Db db = MainWindow.Toplevel.Database;	
+		db.BeginTransaction ();
+		foreach (string tagname in new_tags) {
+			Tag t = db.Tags.GetTagByName (tagname);
+			if (t == null) {
+				Category default_category = db.Tags.GetTagByName (Catalog.GetString ("Import Tags")) as Category;
+				if (default_category == null) {
+					default_category = db.Tags.CreateCategory (null, Catalog.GetString ("Import Tags"));
+					default_category.ThemeIconName = "f-spot-imported-xmp-tags.png"; 
+				}
+				t = db.Tags.CreateCategory (default_category, tagname) as Tag;
+				db.Tags.Commit (t);
+			}
 
-	private void HandleNewTagSelected (object sender, EventArgs args)
-	{
-		Tag new_tag = MainWindow.Toplevel.CreateTag (Dialog, null);
-
-		if (new_tag != null) {
-			CreateTagMenu ();
-			tag_option_menu.SetHistory ((uint) (tag_option_menu.Menu as TagMenu).GetPosition (new_tag));
-			tag_selected = new_tag;
+			tags_selected.Add (t);
 		}
+		db.CommitTransaction ();
+		
+		ArrayList tagnames = new ArrayList ();
+		foreach (Tag t in tags_selected)
+			tagnames.Add (t.Name);
+		tag_entry.UpdateFromTagNames ((string [])tagnames.ToArray(typeof(string)));
 	}
 
 	public void Cancel ()
@@ -733,7 +776,8 @@ public class ImportCommand : FSpot.GladeDialog {
 		if (recurse_check != null)
 			recurse = recurse_check.Active;
 		
-		importer = new FileImportBackend (store, pathimport, copy, recurse, null);
+//		importer = new FileImportBackend (store, pathimport, copy, recurse, null);
+		importer = new FileImportBackend (store, pathimport, copy, recurse, null, Dialog);
 		AllowFinish = false;
 		
 		total = importer.Prepare ();
@@ -763,7 +807,7 @@ public class ImportCommand : FSpot.GladeDialog {
 	public int ImportFromPaths (PhotoStore store, string [] paths, Tag [] tags, bool copy)
 	{
 		collection = new FSpot.PhotoList (new Photo [0]);
-		int count = DoImport (new FileImportBackend (store, paths, copy, true, tags));
+		int count = DoImport (new FileImportBackend (store, paths, copy, true, tags, main_window ));
 
 		Finish ();
 
