@@ -1,7 +1,7 @@
 using System;
 using SemWeb;
 using System.IO;
-
+using FSpot.Utils;
 using Mono.Unix;
 
 namespace FSpot {
@@ -148,7 +148,11 @@ namespace FSpot {
 
 		private void Update ()
 		{
+#if GTKHTML_3_14
+			Gtk.HTMLStream stream = this.Begin (null, "text/html; charset=utf-8", Gtk.HTMLBeginFlags.KeepScroll);
+#else
 			Gtk.HTMLStream stream = this.Begin (null, "text/html; charset=utf-8", Gtk.HTMLBeginFlags.Scroll);
+#endif
 			
 			string bg = Color (this.Style.Background (Gtk.StateType.Active));
 			string fg = Color (this.Style.Foreground (Gtk.StateType.Active));
@@ -321,9 +325,9 @@ namespace FSpot {
 			
 			stream.Write ("<table cellpadding=5 cellspacing=0 width=100%>");
 			foreach (Statement sub in substore) {
-				if (sub.Object is Literal) {
+				if (sub.Object is SemWeb.Literal) {
 					string title;
-					string value = ((Literal)(sub.Object)).Value;
+					string value = ((SemWeb.Literal)(sub.Object)).Value;
 					string vc = String.Empty;
 					
 					Description.GetDescription (substore, sub, out title, out value);
