@@ -1,7 +1,13 @@
+#if CAIRO_1_2_5
+extern alias MCairo;
+#else
+using Cairo;
+#endif
+
 using Gtk;
+using Gdk;
 using System;
 using System.Runtime.InteropServices;
-using Cairo;
 using Mono.Unix;
 using FSpot.Widgets;
 using FSpot.UI.Dialog;
@@ -302,14 +308,23 @@ namespace FSpot {
 							    Allocation.Width, 
 							    Allocation.Height, 1);
 			
+#if CAIRO_1_2_5
+			MCairo::Cairo.Context g = CairoHelper.Create (bitmap);
+#else			
 			Context g = CairoUtils.CreateContext (bitmap);
+#endif			
 			DrawShape (g, Allocation.Width, Allocation.Height);
+			
 			((IDisposable)g).Dispose ();
 
 			if (use_shape_ext)
 				ShapeCombineMask (bitmap, 0, 0);
 			else {
+#if CAIRO_1_2_5			 
+				MCairo::Cairo.Context rgba = CairoHelper.Create (GdkWindow);
+#else				
 				Context rgba = CairoUtils.CreateContext (GdkWindow);
+#endif				
 				DrawShape (rgba, Allocation.Width, Allocation.Height);
 				((IDisposable)rgba).Dispose ();
 				try {
@@ -340,33 +355,52 @@ namespace FSpot {
 			hotspot.X = (int) Math.Ceiling (Center.X + x_proj);
 			hotspot.Y = (int) Math.Ceiling (Center.Y + y_proj);
 		}
-		
-		private void DrawShape (Cairo.Context g, int width, int height)
+	
+#if CAIRO_1_2_5		
+		private void DrawShape (MCairo::Cairo.Context g, int width, int height)
+#else
+		private void DrawShape (Context g, int width, int height)
+#endif				
 		{
 			int inner_x = radius + border + inner;
 			int cx = Center.X;
 			int cy = Center.Y;
-			
+		
+#if CAIRO_1_2_5			
+			g.Operator = MCairo::Cairo.Operator.Source;
+			g.Source = new MCairo::Cairo.SolidPattern (new MCairo::Cairo.Color (0,0,0,0));
+#else
 			g.Operator = Operator.Source;
 			g.Source = new SolidPattern (new Cairo.Color (0,0,0,0));
+#endif						
 			g.Rectangle (0, 0, width, height);
 			g.Paint ();
 
 			g.NewPath ();
 			g.Translate (cx, cy);
 			g.Rotate (angle);
-			
+
+#if CAIRO_1_2_5			
+			g.Source = new MCairo::Cairo.SolidPattern (new MCairo::Cairo.Color (0.2, 0.2, 0.2, .6));
+			g.Operator = MCairo::Cairo.Operator.Over;
+#else
 			g.Source = new SolidPattern (new Cairo.Color (0.2, 0.2, 0.2, .6));
 			g.Operator = Operator.Over;
+#endif						
 			g.Rectangle (0, - (border + inner), inner_x, 2 * (border + inner));
 			g.Arc (inner_x, 0, inner + border, 0, 2 * Math.PI);
 			g.Arc (0, 0, radius + border, 0, 2 * Math.PI);
 			g.Fill ();
 
+#if CAIRO_1_2_5
+			g.Source = new MCairo::Cairo.SolidPattern (new MCairo::Cairo.Color (0, 0, 0, 1.0));
+			g.Operator = MCairo::Cairo.Operator.DestOut;
+#else
 			g.Source = new SolidPattern (new Cairo.Color (0, 0, 0, 1.0));
 			g.Operator = Operator.DestOut;
+#endif						
 			g.Arc (inner_x, 0, inner, 0, 2 * Math.PI);
-#if true
+#if true			
 			g.Fill ();
 #else
 			g.FillPreserve ();
@@ -380,28 +414,65 @@ namespace FSpot {
 			g.Fill ();
 			rg.Destroy ();
 #endif
+#if CAIRO_1_2_5			
+			g.Operator = MCairo::Cairo.Operator.Over;
+			g.Matrix = new MCairo::Cairo.Matrix ();
+#else			
 			g.Operator = Operator.Over;
 			g.Matrix = new Matrix ();
+#endif			
 			g.Translate (cx, cy);
 			if (source != null)
+#if CAIRO_1_2_5			 
+				CairoHelper.SetSourcePixbuf (g, source, -source.Width / 2, -source.Height / 2);
+#else
 				SetSourcePixbuf (g, source, -source.Width / 2, -source.Height / 2);
+#endif								
 
 			g.Arc (0, 0, radius, 0, 2 * Math.PI);
 			g.Fill ();
 
 			if (overlay != null) {
+#if CAIRO_1_2_5			 
+				CairoHelper.SetSourcePixbuf (g, overlay, -overlay.Width / 2, -overlay.Height / 2);
+#else
 				SetSourcePixbuf (g, overlay, -overlay.Width / 2, -overlay.Height / 2);
+
+#endif
 				g.Arc (0, 0, radius, angle, angle + Math.PI);
 				g.ClosePath ();
 				g.FillPreserve ();
+#if CAIRO_1_2_5				
+				g.Source = new MCairo::Cairo.SolidPattern (new MCairo::Cairo.Color (1.0, 1.0, 1.0, 1.0));
+#else
 				g.Source = new SolidPattern (new Cairo.Color (1.0, 1.0, 1.0, 1.0));
+#endif								
 				g.Stroke ();
 			}
 		}
 
+#if !CAIRO_1_2_5
+		[DllImport("libgdk-2.0-0.dll")] 	 
+	        extern static void gdk_cairo_set_source_pixbuf (IntPtr handle, 	 
+	                                                        IntPtr pixbuf, 	 
+	                                                        double        pixbuf_x, 	 
+	                                                        double        pixbuf_y); 	 
+	  	 
+	        [Obsolete ("use Gdk.CairoHelper.SetSourcePixbuf instead")] 	 
+	        static void SetSourcePixbuf (Context ctx, Gdk.Pixbuf pixbuf, double x, double y) 	 
+	        { 	 
+	                gdk_cairo_set_source_pixbuf (ctx.Handle, pixbuf.Handle, x, y); 	 
+	        } 	 
+#endif				
+
 		protected override bool OnExposeEvent (Gdk.EventExpose args)
 		{
-			Context g = CairoUtils.CreateContext (GdkWindow);
+#if CAIRO_1_2_5		 
+			MCairo::Cairo.Context g = CairoHelper.Create (GdkWindow);
+#else
+			Context g = CairoUtils.CreateContext (GdkWindow);			
+#endif						
+			
 			DrawShape (g, Allocation.Width, Allocation.Height);
 			//base.OnExposeEvent (args);
 			((IDisposable)g).Dispose ();
@@ -409,6 +480,19 @@ namespace FSpot {
 
 		}
 		
+                [DllImport ("libcairo-2.dll")]
+                static extern void cairo_user_to_device (IntPtr cr, ref double x, ref double y);
+
+#if CAIRO_1_2_5
+		static void UserToDevice (MCairo::Cairo.Context ctx, ref double x, ref double y)
+#else		
+		static void UserToDevice (Context ctx, ref double x, ref double y)
+#endif		
+		{
+			cairo_user_to_device (ctx.Handle, ref x, ref y);
+		}
+
+		
 		bool dragging = false;
 		bool rotate = false;
 		Delay drag;
@@ -557,26 +641,6 @@ namespace FSpot {
 			return widget;
 		}
 		
-		
-                [DllImport ("libcairo-2.dll")]
-                static extern void cairo_user_to_device (IntPtr cr, ref double x, ref double y);
-
-		static void UserToDevice (Context ctx, ref double x, ref double y)
-		{
-			cairo_user_to_device (ctx.Handle, ref x, ref y);
-		}
-
-		[DllImport("libgdk-2.0-0.dll")]
-		extern static void gdk_cairo_set_source_pixbuf (IntPtr handle,
-								IntPtr pixbuf,
-								double        pixbuf_x,
-								double        pixbuf_y);
-
-		static void SetSourcePixbuf (Context ctx, Gdk.Pixbuf pixbuf, double x, double y)
-		{
-			gdk_cairo_set_source_pixbuf (ctx.Handle, pixbuf.Handle, x, y);
-		}
-
 		protected override void OnSizeRequested (ref Requisition requisition) 
 		{
 			Layout ();
