@@ -80,6 +80,7 @@ public class MainWindow {
 	[Glade.Widget] CheckMenuItem display_toolbar;
 	[Glade.Widget] CheckMenuItem display_sidebar;
 	[Glade.Widget] CheckMenuItem display_timeline;
+	[Glade.Widget] CheckMenuItem display_filmstrip;
 	[Glade.Widget] CheckMenuItem display_dates_menu_item;
 	[Glade.Widget] CheckMenuItem display_tags_menu_item;
 	[Glade.Widget] CheckMenuItem display_ratings_menu_item;
@@ -454,6 +455,7 @@ public class MainWindow {
 		LoadPreference (Preferences.SHOW_TOOLBAR);
 		LoadPreference (Preferences.SHOW_SIDEBAR);
 		LoadPreference (Preferences.SHOW_TIMELINE);
+		LoadPreference (Preferences.SHOW_FILMSTRIP);
 
 		LoadPreference (Preferences.GNOME_MAILTO_ENABLED);
 		
@@ -508,7 +510,11 @@ public class MainWindow {
 		case ModeType.IconView:
 			if (view_notebook.CurrentPage != 0)
 				view_notebook.CurrentPage = 0;
-				
+
+			display_timeline.Sensitive = true;
+			display_filmstrip.Sensitive = false;
+			group_selector.Visible = group_selector.Sensitive = display_timeline.Active;
+
 			ColorDialog.Close ();
 			if (photo_view.View.Loupe != null)
 				photo_view.View.Loupe.Destroy ();
@@ -518,6 +524,10 @@ public class MainWindow {
 		case ModeType.PhotoView:
 			if (view_notebook.CurrentPage != 1)
 				view_notebook.CurrentPage = 1;
+
+			display_timeline.Sensitive = false;
+			display_filmstrip.Sensitive = true;
+			group_selector.Visible = group_selector.Sensitive = false;
 			
 			JumpTo (icon_view.FocusCell);
 			zoom_scale.Value = photo_view.NormalizedZoom;
@@ -1533,7 +1543,12 @@ public class MainWindow {
 	
 	void HandlePrintCommand (object sender, EventArgs e)
 	{
+#if !GTK_2_10
 		new FSpot.PrintDialog (SelectedPhotos ());
+#else
+		FSpot.PrintOperation print = new FSpot.PrintOperation (SelectedPhotos ());
+		print.Run (PrintOperationAction.PrintDialog, null);
+#endif
 	}
 
 	private Gtk.Dialog info_display_window;
@@ -1743,7 +1758,8 @@ public class MainWindow {
 
 		Preferences.Set (Preferences.SHOW_TOOLBAR,		toolbar.Visible);
 		Preferences.Set (Preferences.SHOW_SIDEBAR,		info_vbox.Visible);
-		Preferences.Set (Preferences.SHOW_TIMELINE,		group_selector.Visible);
+		Preferences.Set (Preferences.SHOW_TIMELINE,		display_timeline.Active);
+		Preferences.Set (Preferences.SHOW_FILMSTRIP,		display_filmstrip.Active);
 		Preferences.Set (Preferences.SHOW_TAGS,			icon_view.DisplayTags);
 		Preferences.Set (Preferences.SHOW_DATES,		icon_view.DisplayDates);
 		Preferences.Set (Preferences.SHOW_RATINGS,		icon_view.DisplayRatings);
@@ -1960,64 +1976,13 @@ public class MainWindow {
 
 	void HandleSharpen (object sender, EventArgs args)
 	{
-		Gtk.Dialog dialog = new Gtk.Dialog (Catalog.GetString ("Unsharp Mask"), main_window, Gtk.DialogFlags.Modal);
-
-		dialog.VBox.Spacing = 6;
-		dialog.VBox.BorderWidth = 12;
-		
-		Gtk.Table table = new Gtk.Table (3, 2, false);
-		table.ColumnSpacing = 6;
-		table.RowSpacing = 6;
-		
-		table.Attach (new Gtk.Label (Catalog.GetString ("Amount:")), 0, 1, 0, 1);
-		table.Attach (new Gtk.Label (Catalog.GetString ("Radius:")), 0, 1, 1, 2);
-		table.Attach (new Gtk.Label (Catalog.GetString ("Threshold:")), 0, 1, 2, 3);
-
-		Gtk.SpinButton amount_spin = new Gtk.SpinButton (0.5, 100.0, .01);
-		Gtk.SpinButton radius_spin = new Gtk.SpinButton (5.0, 50.0, .01);
-		Gtk.SpinButton threshold_spin = new Gtk.SpinButton (0.0, 50.0, .01);
-
-		table.Attach (amount_spin, 1, 2, 0, 1);
-		table.Attach (radius_spin, 1, 2, 1, 2);
-		table.Attach (threshold_spin, 1, 2, 2, 3);
-		
-		dialog.VBox.PackStart (table);
-
-		dialog.AddButton (Gtk.Stock.Cancel, Gtk.ResponseType.Cancel);
-		dialog.AddButton (Gtk.Stock.Ok, Gtk.ResponseType.Ok);
-
-		dialog.ShowAll ();
-
-		Gtk.ResponseType response = (Gtk.ResponseType) dialog.Run ();
-
-		if (response == Gtk.ResponseType.Ok) {
-			foreach (int id in SelectedIds ()) {
-				Photo photo = query.Photos [id];
-				try {
-					Gdk.Pixbuf orig = FSpot.PhotoLoader.Load (query, id);
-					Gdk.Pixbuf final = PixbufUtils.UnsharpMask (orig, radius_spin.Value, amount_spin.Value, threshold_spin.Value);
-					
-					bool create_version = photo.DefaultVersion.IsProtected;
-
-					photo.SaveVersion (final, create_version);
-					query.Commit (id);
-				} catch (System.Exception e) {
-					string msg = Catalog.GetString ("Error saving sharpened photo");
-					string desc = String.Format (Catalog.GetString ("Received exception \"{0}\". Unable to save photo {1}"),
-								     e.Message, photo.Name.Replace ("_", "__"));
-					
-					HigMessageDialog md = new HigMessageDialog (main_window, DialogFlags.DestroyWithParent, 
-										    Gtk.MessageType.Error, ButtonsType.Ok, 
-										    msg,
-										    desc);
-					md.Run ();
-					md.Destroy ();
-				}
-			
-			}
+		// Don't steal characters from any text entries
+		if (Window.Focus is Gtk.Entry && Gtk.Global.CurrentEvent is Gdk.EventKey) {
+			Window.Focus.ProcessEvent (Gtk.Global.CurrentEvent);
+			return;
 		}
-
-		dialog.Destroy ();
+		
+		photo_view.View.ShowSharpener ();
 	}
 
 	void HandleDisplayToolbar (object sender, EventArgs args)
@@ -2054,6 +2019,11 @@ public class MainWindow {
 			group_selector.Show ();
 	}
 
+	void HandleDisplayFilmstrip (object sender, EventArgs args)
+	{
+		photo_view.FilmStripVisibility = display_filmstrip.Active;
+	}
+
 	void HandleDisplayInfoSidebar (object sender, EventArgs args)
 	{
 		if (info_vbox.Visible)
@@ -2064,18 +2034,7 @@ public class MainWindow {
 
 	void HandleViewSlideShow (object sender, EventArgs args)
 	{
-		int active = Math.Max (ActiveIndex (), 0);
-		if (fsview == null) {
-			fsview = new FSpot.FullScreenView (query);
-			fsview.Destroyed += HandleFullScreenViewDestroy;
-			fsview.View.Item.Index = active;
-			ColorDialog.SwitchViews (fsview.View);
-		} else {
-			// FIXME this needs to be another mode like PhotoView and IconView mode.
-			fsview.View.Item.Index = active;
-		}
-		
-		fsview.Show ();
+		HandleViewFullscreen (sender, args);
 		fsview.PlayPause ();
 	}
 
@@ -2109,7 +2068,7 @@ public class MainWindow {
 	{
 		int active = Math.Max (ActiveIndex (), 0);
 		if (fsview == null) {
-			fsview = new FSpot.FullScreenView (query);
+			fsview = new FSpot.FullScreenView (query, main_window);
 			fsview.Destroyed += HandleFullScreenViewDestroy;
 			fsview.View.Item.Index = active;
 			ColorDialog.SwitchViews (fsview.View);
@@ -2612,6 +2571,11 @@ public class MainWindow {
 				display_timeline.Active = (bool) val;
 			break;
 		
+		case Preferences.SHOW_FILMSTRIP:
+			if (display_filmstrip.Active != (bool) val)
+				display_filmstrip.Active = (bool) val;
+			break;
+		
 		case Preferences.SHOW_TAGS:
 			if (display_tags_menu_item.Active != (bool) val)
 				display_tags_menu_item.Active = (bool) val;
@@ -2817,6 +2781,7 @@ public class MainWindow {
 			delete_version_menu_item.Sensitive = false;
 			rename_version_menu_item.Sensitive = false;
 
+			sharpen.Sensitive = false;
 		} else {
 			version_menu_item.Sensitive = true;
 			create_version_menu_item.Sensitive = true;
@@ -2832,6 +2797,8 @@ public class MainWindow {
 			versions_submenu = new PhotoVersionMenu (CurrentPhoto);
 			versions_submenu.VersionIdChanged += new PhotoVersionMenu.VersionIdChangedHandler (HandleVersionIdChanged);
 			version_menu_item.Submenu = versions_submenu;
+
+			sharpen.Sensitive = (view_mode == ModeType.IconView ? false : true);
 		}
 
 		set_as_background.Sensitive = single_active;
@@ -2851,7 +2818,6 @@ public class MainWindow {
 		select_none.Sensitive = active_selection;
 		copy_location.Sensitive = active_selection;
 		exif_data.Sensitive = active_selection;
-		sharpen.Sensitive = active_selection;
 		remove_from_catalog.Sensitive = active_selection;
 		
 		clear_rating_filter.Sensitive = (query.RatingRange != null);
@@ -3022,7 +2988,7 @@ public class MainWindow {
 
 	public void HandlePossibleTagTyping (object sender, Gtk.KeyPressEventArgs args)
 	{
-		if (tagbar.Visible && tag_entry.HasFocus)
+		if (Selection.Count == 0 || tagbar.Visible && tag_entry.HasFocus)
 			return;
 
 #if !ALLOW_TAG_TYPING_WITHOUT_HOTKEY
