@@ -20,7 +20,11 @@ namespace FSpot {
 		public GdkGlx.Context Glx;
 		private Editor editor;
 
-		public PhotoImageView (IBrowsableCollection query)
+		public PhotoImageView (IBrowsableCollection query) : this (new BrowsablePointer (query, -1))
+		{
+		}
+
+		public PhotoImageView (BrowsablePointer item)
 		{
 			loader = new FSpot.AsyncPixbufLoader ();
 			loader.AreaUpdated += HandlePixbufAreaUpdated;
@@ -36,7 +40,7 @@ namespace FSpot {
 			//this.Realized += HandleRealized;
 			this.Unrealized += HandleUnrealized;
 			this.ScrollEvent += HandleScrollEvent;
-			this.item = new BrowsablePointer (query, -1);
+			this.item = item;
 			item.Changed += PhotoItemChanged;
 			this.Destroyed += HandleDestroyed;
 			this.SetTransparentColor (this.Style.BaseColors [(int)Gtk.StateType.Normal]);
@@ -474,14 +478,6 @@ namespace FSpot {
 			case Gdk.Key.KP_Subtract:
 				ZoomOut ();
 				break;
-			case Gdk.Key.s:
-				if (sharpener == null) {
-					sharpener = new Sharpener (this);
-					sharpener.Destroyed += HandleLoupeDestroy;
-				}
-
-				sharpener.Show ();
-				break;
 			case Gdk.Key.v:
 				if (loupe == null) {
 					loupe = new Loupe (this);
@@ -506,6 +502,16 @@ namespace FSpot {
 
 			return;
 		}
+
+		public void ShowSharpener ()
+		{
+			if (sharpener == null) {
+				sharpener = new Sharpener (this);
+				sharpener.Destroyed += HandleLoupeDestroy;
+			}
+
+			sharpener.Show ();	
+		}
 		
 		[GLib.ConnectBefore]
 		private void HandleScrollEvent (object sender, Gtk.ScrollEventArgs args)
