@@ -2,6 +2,8 @@ using Gtk;
 using Glade;
 using System;
 using Mono.Unix;
+using FSpot;
+using FSpot.UI.Dialog;
 
 public class PhotoVersionCommands {
 
@@ -26,13 +28,13 @@ public class PhotoVersionCommands {
 
 			if (photo.VersionNameExists (new_name)
 			    && ! (request_type == RequestType.Rename
-				  && new_name == photo.GetVersionName (photo.DefaultVersionId))) {
+				  && new_name == photo.GetVersion (photo.DefaultVersionId).Name)) {
 				already_in_use_label.Markup = "<small>This name is already in use</small>";
 				ok_button.Sensitive = false;
 				return;
 			}
 
-			already_in_use_label.Text = "";
+			already_in_use_label.Text = String.Empty;
 			
 			if (new_name.Length == 0)
 				ok_button.Sensitive = false;
@@ -59,7 +61,7 @@ public class PhotoVersionCommands {
 			case RequestType.Rename:
 				this.Dialog.Title = Catalog.GetString ("Rename Version");
 				prompt_label.Text = Catalog.GetString ("New name:");
-				version_name_entry.Text = photo.GetVersionName (photo.DefaultVersionId);
+				version_name_entry.Text = photo.GetVersion (photo.DefaultVersionId).Name;
 				version_name_entry.SelectRegion (0, -1);
 				break;
 			}
@@ -77,7 +79,7 @@ public class PhotoVersionCommands {
 			ResponseType response = (ResponseType) this.Dialog.Run ();
 
 			name = version_name_entry.Text;
-			if (request_type == RequestType.Rename && name == photo.GetVersionName (photo.DefaultVersionId))
+			if (request_type == RequestType.Rename && name == photo.GetVersion (photo.DefaultVersionId).Name)
 				response = ResponseType.Cancel;
 
 			this.Dialog.Destroy ();
@@ -137,7 +139,7 @@ public class PhotoVersionCommands {
 			dialog.AddButton (Catalog.GetString ("Delete"), (int) ResponseType.Ok);
 			dialog.DefaultResponse = ResponseType.Ok;
 
-			string version_name = photo.GetVersionName (photo.DefaultVersionId);
+			string version_name = photo.GetVersion (photo.DefaultVersionId).Name;
 			Label label = new Label (String.Format (Catalog.GetString ("Really delete version \"{0}\"?"), version_name));
 			label.Show ();
 			dialog.VBox.PackStart (label, false, true, 6);;
@@ -206,4 +208,34 @@ public class PhotoVersionCommands {
 			return true;
 		}
 	}
+
+	// Reparenting a photo as version of another one
+	public class Reparent {
+		public bool Execute (PhotoStore store, Photo [] photos, Photo new_parent, Gtk.Window parent_window)
+		{
+			foreach (Photo photo in photos) {
+				new_parent.AddTag (photo.Tags);
+				foreach (uint version_id in photo.VersionIds) {
+					try {
+						new_parent.DefaultVersionId = new_parent.CreateReparentedVersion (photo.GetVersion (version_id) as PhotoVersion);
+						store.Commit (new_parent);
+					} catch (Exception e) {
+						Console.WriteLine (e);	
+					}
+				}
+				uint [] version_ids = photo.VersionIds;
+				Array.Reverse (version_ids);
+				foreach (uint version_id in version_ids) {
+					try {
+						photo.DeleteVersion (version_id, true, true);
+					} catch (Exception e) {
+						Console.WriteLine(e);
+					}
+				}
+				store.Commit (photo);
+				MainWindow.Toplevel.Database.Photos.Remove (photo);
+			}
+			return true;
+		}
+	}
 }
