@@ -32,6 +32,7 @@ namespace FSpot {
 		[Glade.Widget] private FileChooserButton photosdir_chooser;
 		[Glade.Widget] private RadioButton screensaverall_radio;
 		[Glade.Widget] private RadioButton screensavertagged_radio;
+		[Glade.Widget] private CheckButton dbus_check;
 		private static PreferenceDialog prefs = null;
 		int screensaver_tag;
 		private const string SaverCommand = "screensavers-f-spot-screensaver";
@@ -42,13 +43,14 @@ namespace FSpot {
 			LoadPreference (Preferences.METADATA_EMBED_IN_IMAGE);
 			LoadPreference (Preferences.SCREENSAVER_TAG);
 			LoadPreference (Preferences.GNOME_SCREENSAVER_THEME);
-			if (!Global.CustomPhotoDirectory) {
+			if (Global.PhotoDirectory == (string)Preferences.Get(Preferences.STORAGE_PATH)) {
 				photosdir_chooser.CurrentFolderChanged += HandlePhotosdirChanged;
 				photosdir_chooser.SetCurrentFolder (Global.PhotoDirectory);
 			} else {
 				photosdir_chooser.SetCurrentFolder(Global.PhotoDirectory);
 				photosdir_chooser.Sensitive = false;
 			}
+			LoadPreference (Preferences.DBUS_READ_ONLY);
 
 			Gtk.CellRendererText name_cell = new Gtk.CellRendererText ();
 			Gtk.CellRendererText desc_cell = new Gtk.CellRendererText ();
@@ -120,7 +122,7 @@ namespace FSpot {
 				HandleTagMenuSelected (((tag_option.Menu as Menu).Active as TagMenu.TagMenuItem).Value);
 		}
 
-		void OnPreferencesChanged (object sender, GConf.NotifyEventArgs args)
+		void OnPreferencesChanged (object sender, NotifyEventArgs args)
 		{
 			LoadPreference (args.Key);
 		}
@@ -130,6 +132,14 @@ namespace FSpot {
 			Preferences.Set (Preferences.METADATA_EMBED_IN_IMAGE, metadata_check.Active);
 		}
 
+		void DBusReadOnlyToggled (object sender, System.EventArgs args)
+		{
+			Preferences.Set (Preferences.DBUS_READ_ONLY, !dbus_check.Active); 
+
+			DBusProxyFactory.EmitRemoteDown ();
+			DBusProxyFactory.Load (MainWindow.Toplevel.Database);
+		}
+
 		void HandlePhotosdirChanged (object sender, System.EventArgs args)
 		{
 			Preferences.Set (Preferences.STORAGE_PATH, photosdir_chooser.Filename);
@@ -173,6 +183,9 @@ namespace FSpot {
 			case Preferences.STORAGE_PATH:
 				photosdir_chooser.SetCurrentFolder ((string)val);
 				break;
+			case Preferences.DBUS_READ_ONLY:
+				dbus_check.Active = !((bool)val);
+				break;
 			}
 		}
 
