@@ -9,6 +9,7 @@ namespace FSpot
 	{
 		public const string APP_FSPOT = "/apps/f-spot/";
 		public const string APP_FSPOT_EXPORT = APP_FSPOT + "export/";
+		public const string APP_FSPOT_EXPORT_TOKENS = APP_FSPOT_EXPORT + "tokens/";
 
 		public const string MAIN_WINDOW_MAXIMIZED = "/apps/f-spot/ui/maximized";
 
@@ -29,10 +30,12 @@ namespace FSpot
 		public const string VIEWER_INTERPOLATION = "/apps/f-spot/viewer/interpolation";
 		public const string VIEWER_TRANS_COLOR = "/apps/f-spot/viewer/trans_color";
 		public const string VIEWER_TRANSPARENCY = "/apps/f-spot/viewer/transparency";
+		public const string CUSTOM_CROP_RATIOS = "/apps/f-spot/viewer/custom_crop_ratios";
 		
 		public const string SHOW_TOOLBAR = "/apps/f-spot/ui/show_toolbar";
 		public const string SHOW_SIDEBAR = "/apps/f-spot/ui/show_sidebar";
 		public const string SHOW_TIMELINE = "/apps/f-spot/ui/show_timeline";
+		public const string SHOW_FILMSTRIP = "/apps/f-spot/ui/show_filmstrip";
 		public const string SHOW_TAGS = "/apps/f-spot/ui/show_tags";
 		public const string SHOW_DATES = "/apps/f-spot/ui/show_dates";
 		public const string EXPANDED_TAGS = "/apps/f-spot/ui/expanded_tags";
@@ -46,24 +49,6 @@ namespace FSpot
 		public const string SIDEBAR_POSITION = "/apps/f-spot/ui/sidebar_size";
 		public const string ZOOM = "/apps/f-spot/ui/zoom";
 
-		public const string EXPORT_TOKEN_FLICKR = "/apps/f-spot/export/tokens/flickr"; 
-		public const string EXPORT_TOKEN_23HQ = "/apps/f-spot/export/tokens/23hq"; 
-		public const string EXPORT_TOKEN_ZOOOMR = "/apps/f-spot/export/tokens/zooomr"; 
-
-		public const string EXPORT_SMUGMUG_SCALE = "/apps/f-spot/export/smugmug/scale";
-		public const string EXPORT_SMUGMUG_SIZE = "/apps/f-spot/export/smugmug/size";
-		public const string EXPORT_SMUGMUG_ROTATE = "/apps/f-spot/export/smugmug/rotate";
-		public const string EXPORT_SMUGMUG_BROWSER = "/apps/f-spot/export/smugmug/browser";
-
-		public const string EXPORT_FOLDER_SCALE = "/apps/f-spot/export/folder/scale";
-		public const string EXPORT_FOLDER_SIZE = "/apps/f-spot/export/folder/size";
-		public const string EXPORT_FOLDER_OPEN = "/apps/f-spot/export/folder/browser";
-		public const string EXPORT_FOLDER_ROTATE = "/apps/f-spot/export/folder/rotate";
-		public const string EXPORT_FOLDER_METHOD = "/apps/f-spot/export/folder/method";
-		public const string EXPORT_FOLDER_URI = "/apps/f-spot/export/folder/uri";
-		public const string EXPORT_FOLDER_SHARPEN = "/apps/f-spot/export/folder/sharpen";
-		public const string EXPORT_FOLDER_INCLUDE_TARBALLS = "/apps/f-spot/export/folder/include_tarballs";
-		
 		public const string EXPORT_EMAIL_SIZE = "/apps/f-spot/export/email/size";
 		public const string EXPORT_EMAIL_ROTATE = "/apps/f-spot/export/email/auto_rotate";
 		public const string EXPORT_EMAIL_DELETE_TIMEOUT_SEC = "/apps/f-spot/export/email/delete_timeout_seconds";
@@ -100,7 +85,13 @@ namespace FSpot
 			get {
 				if (backend == null) {
 #if !NOGCONF
-					backend = new GConfPreferenceBackend ();
+					try {
+						backend = new GConfPreferenceBackend ();
+					} catch (Exception ex) {
+						Console.WriteLine ("Couldn't load Gconf. Check that gconf-daemon is running.{0}{1}",
+							Environment.NewLine, ex);
+						backend = new NullPreferenceBackend ();
+					}
 #else
 					backend = new NullPreferenceBackend ();
 #endif
@@ -142,23 +133,14 @@ namespace FSpot
 			case SHOW_TOOLBAR:
 			case SHOW_SIDEBAR:
 			case SHOW_TIMELINE:
+			case SHOW_FILMSTRIP:
 			case SHOW_TAGS:
 			case SHOW_DATES:
 			case SHOW_RATINGS:
 			case VIEWER_SHOW_FILENAMES:
-			case EXPORT_SMUGMUG_SCALE:
-			case EXPORT_SMUGMUG_ROTATE:
-			case EXPORT_SMUGMUG_BROWSER:
-			case EXPORT_FOLDER_SCALE:
-			case EXPORT_FOLDER_SHARPEN:
-			case EXPORT_FOLDER_INCLUDE_TARBALLS:
 			case DBUS_READ_ONLY:
 				return true;
 			
-			case EXPORT_SMUGMUG_SIZE:
-			case EXPORT_FOLDER_SIZE:
-				return 800;
-				
 			case TAG_ICON_SIZE:
 				return (int) Tag.IconSize.Large;
 		
@@ -176,14 +158,10 @@ namespace FSpot
 			case EXPORT_EMAIL_SIZE:
 				return 3;	// medium size 640px
 			case EXPORT_EMAIL_ROTATE:
-			case EXPORT_FOLDER_OPEN:
-			case EXPORT_FOLDER_ROTATE:
 			case VIEWER_INTERPOLATION:
 				return true;
 			case EXPORT_EMAIL_DELETE_TIMEOUT_SEC:
 				return 30;	// delete temporary email pictures after 30 seconds
-			case EXPORT_FOLDER_METHOD:
-				return "static";
 			case VIEWER_TRANSPARENCY:
 				return "NONE";
 			case VIEWER_TRANS_COLOR:
@@ -198,7 +176,6 @@ namespace FSpot
 			case PROXY_USER:
 			case PROXY_PASSWORD:
 				return String.Empty;
-			
 			default:
 				return null;
 			}
