@@ -3,6 +3,8 @@ using Gtk;
 using GtkSharp;
 using System;
 
+using Mono.Unix;
+
 public class ProgressDialog : Gtk.Dialog {
 
 	private bool cancelled;
@@ -18,7 +20,6 @@ public class ProgressDialog : Gtk.Dialog {
 		None
 	};
 
-	private CancelButtonType cancel_button_type;
 	private int total_count;
 
 	private ProgressBar progress_bar;
@@ -43,7 +44,6 @@ public class ProgressDialog : Gtk.Dialog {
 	public ProgressDialog (string title, CancelButtonType cancel_button_type, int total_count, Gtk.Window parent_window)
 	{
 		Title = title;
-		this.cancel_button_type = cancel_button_type;
 		this.total_count = total_count;
 
 		if (parent_window != null)
@@ -53,7 +53,7 @@ public class ProgressDialog : Gtk.Dialog {
 		BorderWidth = 6;
 		SetDefaultSize (300, -1);
 
-		message_label = new Label ("");
+		message_label = new Label (String.Empty);
 		VBox.PackStart (message_label, true, true, 12);
 
 		progress_bar = new ProgressBar ();
@@ -79,7 +79,7 @@ public class ProgressDialog : Gtk.Dialog {
 		current_count ++;
 
 		message_label.Text = message;
-		progress_bar.Text = String.Format (Mono.Posix.Catalog.GetString ("{0} of {1}"), current_count, total_count);
+		progress_bar.Text = String.Format (Catalog.GetString ("{0} of {1}"), current_count, total_count);
 		progress_bar.Fraction = (double) current_count / total_count;
 
 		ShowAll ();
