@@ -45,14 +45,12 @@ namespace FSpot {
 	public class RotateOperation : Operation {
 		IBrowsableItem item;
 		RotateDirection direction;
-		int version_index;
 		bool done;
 
 		public RotateOperation (IBrowsableItem item, RotateDirection direction)
 		{
 			this.item = item;
 			this.direction = direction;
-			version_index = 0;
 			done = false;
 		}
 
@@ -63,7 +61,7 @@ namespace FSpot {
 					     direction == RotateDirection.Clockwise ? JpegUtils.TransformType.Rotate90 
 					     : JpegUtils.TransformType.Rotate270);
 			
-			Unix.Rename (temporary_path, original_path);
+			Utils.Unix.Rename (temporary_path, original_path);
 		}
 
 		private static void RotateOrientation (string original_path, RotateDirection direction)
@@ -124,15 +122,8 @@ namespace FSpot {
 			if (done)
 				return false;
 
-			if (item is Photo) {
-				Photo p = (Photo) item;
-
-				original_path = p.VersionUri (p.VersionIds [version_index++]).LocalPath;
-				done = (version_index >= p.VersionIds.Length);
-			} else {
-				original_path = item.DefaultVersionUri.LocalPath;
-				done = true;
-			}
+ 			original_path = item.DefaultVersionUri.LocalPath;
+ 			done = true;
 
 			if ((File.GetAttributes(original_path) & FileAttributes.ReadOnly) == FileAttributes.ReadOnly) {
 				throw new RotateException (Catalog.GetString ("Unable to rotate readonly file"), original_path, true);
@@ -209,10 +200,10 @@ public class RotateCommand {
 	        RotateMultiple op = new RotateMultiple (items, direction);
 		int readonly_count = 0;
 		bool done = false;
-		int index = -1;
+		int index = 0;
 
 		while (!done) {
-			if (progress_dialog != null && index != op.Index) 
+			if (progress_dialog != null && op.Index != -1 && index < items.Length) 
 				if (progress_dialog.Update (String.Format (Catalog.GetString ("Rotating photo \"{0}\""), op.Items [op.Index].Name)))
 					break;
 
@@ -232,6 +223,7 @@ public class RotateCommand {
 			} catch (Exception e) {
 				RunGenericError (e, op.Items [op.Index].DefaultVersionUri.LocalPath);
 			}
+			index ++;
 		}
 		
 		if (progress_dialog != null)
