@@ -1,3 +1,5 @@
+using FSpot.Query;
+#if SHOW_CALENDAR
 namespace FSpot {
 	public class SimpleCalendar : Gtk.Calendar {
 		private PhotoQuery parent_query;
@@ -18,7 +20,7 @@ namespace FSpot {
 
 		private void ParentChanged (IBrowsableCollection query)
 		{
-			this.query.Tags = ((PhotoQuery)query).Tags;
+			this.query.Terms = ((PhotoQuery)query).Terms;
 		}
 
 		private void Changed (IBrowsableCollection query)
@@ -50,9 +52,10 @@ namespace FSpot {
 			if (current.Month != last.Month || current.Year != last.Year) {
 				System.Console.WriteLine ("Month thinks is changed {0} {1}", last.ToString (), current.ToString ());
 				last = current;
-				query.Range =  new PhotoStore.DateRange (current, current.AddMonths (1));
+				query.Range =  new DateRange (current, current.AddMonths (1));
 			}
 			base.OnMonthChanged ();
 		}
 	}
 }
+#endif
