@@ -1,9 +1,24 @@
+/*
+ * TagCommand.cs
+ *
+ * Author(s):
+ * 	Larry Ewing <lewing@novell.com>
+ * 	Stephane Delcroix <stephane@delcroix.org>
+ *
+ * This is free software. See COPYING for details
+ */
+
 using Gtk;
 using GtkSharp;
 using System;
 using System.Text;
 using System.Collections;
 
+using Mono.Unix;
+using FSpot;
+using FSpot.Utils;
+using FSpot.UI.Dialog;
+
 public class TagCommands {
 
 	public enum TagType {
@@ -13,15 +28,17 @@ public class TagCommands {
 
 	public class Create : FSpot.GladeDialog {
 		TagStore tag_store;
-		Gtk.Window parent_window;
 
-		[Glade.Widget] private Button ok_button;
+
+		[Glade.Widget] private Button create_button;
 		[Glade.Widget] private Entry tag_name_entry;
 		[Glade.Widget] private Label prompt_label;
 		[Glade.Widget] private Label already_in_use_label;
+		[Glade.Widget] private Label photo_label;
+		[Glade.Widget] private ScrolledWindow photo_scrolled_window;
+		[Glade.Widget] private OptionMenu category_option_menu;
 
-		[Glade.Widget]
-		private OptionMenu category_option_menu;
+		Gtk.Widget parent_window;
 
 		private ArrayList categories;
 
@@ -67,15 +84,15 @@ public class TagCommands {
 
 		private void Update ()
 		{
-			if (tag_name_entry.Text == "") {
-				ok_button.Sensitive = false;
-				already_in_use_label.Markup = "";
+			if (tag_name_entry.Text == String.Empty) {
+				create_button.Sensitive = false;
+				already_in_use_label.Markup = String.Empty;
 			} else if (TagNameExistsInCategory (tag_name_entry.Text, tag_store.RootCategory)) {
-				ok_button.Sensitive = false;
-				already_in_use_label.Markup = "<small>" + Mono.Posix.Catalog.GetString ("This name is already in use") + "</small>";
+				create_button.Sensitive = false;
+				already_in_use_label.Markup = "<small>" + Catalog.GetString ("This name is already in use") + "</small>";
 			} else {
-				ok_button.Sensitive = true;
-				already_in_use_label.Markup = "";
+				create_button.Sensitive = true;
+				already_in_use_label.Markup = String.Empty;
 			}
 		}
 
@@ -119,8 +136,8 @@ public class TagCommands {
 
 			this.Dialog.DefaultResponse = ResponseType.Ok;
 
-			this.Dialog.Title = Mono.Posix.Catalog.GetString ("Create New Tag");
-			prompt_label.Text = Mono.Posix.Catalog.GetString ("Name of New Tag:");
+			this.Dialog.Title = Catalog.GetString ("Create New Tag");
+			prompt_label.Text = Catalog.GetString ("Name of New Tag:");
 
 			PopulateCategoryOptionMenu ();
 			this.Category = default_category;
@@ -194,16 +211,16 @@ public class TagCommands {
 		{
 			string name = tag_name_entry.Text;
 
-			if (name == "") {
+			if (name == String.Empty) {
 				ok_button.Sensitive = false;
-				already_in_use_label.Markup = "";
+				already_in_use_label.Markup = String.Empty;
 			} else if (TagNameExistsInCategory (name, db.Tags.RootCategory)
 				   && String.Compare(name, orig_name, true) != 0) {
 				ok_button.Sensitive = false;
-				already_in_use_label.Markup = "<small>" + Mono.Posix.Catalog.GetString ("This name is already in use") + "</small>";
+				already_in_use_label.Markup = "<small>" + Catalog.GetString ("This name is already in use") + "</small>";
 			} else {
 				ok_button.Sensitive = true;
-				already_in_use_label.Markup = "";
+				already_in_use_label.Markup = String.Empty;
 				last_valid_name = tag_name_entry.Text;
 			}
 		}
@@ -237,23 +254,12 @@ public class TagCommands {
 			Menu menu = new Menu ();
 
 			foreach (Category category in categories) {
-				StringBuilder label_builder = new StringBuilder ();
-				
 				if (t.Category == category)
 					history = i;
 				
 				i++;
 				
-				for (Category parent = category.Category; 
-				     parent != null; 
-				     parent = parent.Category)
-					label_builder.Append ("  ");
-				
-				label_builder.Append (category.Name.Replace ("_", "__"));
-				
-				// FIXME escape underscores.
-				MenuItem item = new MenuItem (label_builder.ToString ());
-				menu.Append (item);
+				menu.Append (TagMenu.TagMenuItem.IndentedItem (category));
 			}
 			
 			category_option_menu.Sensitive = true;
@@ -270,8 +276,8 @@ public class TagCommands {
 			tag = t;
 			this.Dialog.DefaultResponse = ResponseType.Ok;
 
-			this.Dialog.Title = Mono.Posix.Catalog.GetString ("Edit Tag");
-			prompt_label.Text = Mono.Posix.Catalog.GetString ("Tag Name:");
+			this.Dialog.Title = Catalog.GetString ("Edit Tag");
+			prompt_label.Text = Catalog.GetString ("Tag Name:");
 
 			orig_name = last_valid_name = t.Name;
 			tag_name_entry.Text = t.Name;
@@ -292,9 +298,8 @@ public class TagCommands {
 				try {
 					t.Name = last_valid_name;
 					t.Category = categories [category_option_menu.History] as Category;
-					t.Icon = icon_image.Pixbuf;
 
-					db.Tags.Commit (t);
+					db.Tags.Commit (t, orig_name != t.Name);
 					success = true;
 				} catch (Exception ex) {
 					// FIXME error dialog.
@@ -318,13 +323,40 @@ public class TagCommands {
 		Gtk.Window parent_window;
 		FSpot.PhotoQuery query;
 		FSpot.PhotoImageView image_view;
-		IconView icon_view;
+		Gtk.IconView icon_view;
+		ListStore icon_store;
+		string icon_name = null;
+		Gtk.FileChooserButton external_photo_chooser;
+
 
 		[Glade.Widget] Gtk.Image preview_image;
 		[Glade.Widget] ScrolledWindow photo_scrolled_window;
 		[Glade.Widget] ScrolledWindow icon_scrolled_window;
 		[Glade.Widget] Label photo_label;
+		[Glade.Widget] Label from_photo_label;
+		[Glade.Widget] Label from_external_photo_label;
+		[Glade.Widget] private Label predefined_icon_label;
 		[Glade.Widget] SpinButton photo_spin_button;
+		[Glade.Widget] HBox external_photo_chooser_hbox;
+		[Glade.Widget] Button noicon_button;
+
+		private Gdk.Pixbuf PreviewPixbuf {
+			get { return preview_image.Pixbuf; }
+			set {
+				icon_name = null;
+				preview_image.Pixbuf = value;
+			}
+
+		}
+
+		private string IconName {
+			get { return icon_name; }
+			set {
+				icon_name = value;	
+				preview_image.Pixbuf = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, value, 48, (IconLookupFlags) 0);
+			}
+			
+		}
 
 		public FSpot.BrowsablePointer Item {
 			get {
@@ -339,24 +371,52 @@ public class TagCommands {
 			image_view.Item.Index = value;
 		}
 
+		private void HandleExternalFileSelectionChanged (object sender, EventArgs args)
+		{	//Note: The filter on the FileChooserButton's dialog means that we will have a Pixbuf compatible uri here
+			CreateTagIconFromExternalPhoto ();
+		}
+
+		private void CreateTagIconFromExternalPhoto ()
+		{
+			try {
+				using (FSpot.ImageFile img = FSpot.ImageFile.Create(new Uri(external_photo_chooser.Uri))) {
+					using (Gdk.Pixbuf external_image = img.Load ()) {
+						PreviewPixbuf = PixbufUtils.TagIconFromPixbuf (external_image);
+					}
+				}
+			} catch (Exception e) {
+				string caption = Catalog.GetString ("Unable to load image");
+				string message = String.Format (Catalog.GetString ("Unable to load \"{0}\" as icon for the tag"), 
+									external_photo_chooser.Uri.ToString ());
+				HigMessageDialog md = new HigMessageDialog (this.Dialog, 
+									    DialogFlags.DestroyWithParent,
+									    MessageType.Error,
+									    ButtonsType.Close,
+									    caption, 
+									    message);
+				md.Run();
+				md.Destroy();
+			}
+		}
+
 		private void HandleSelectionChanged ()
 		{
 			int x, y, width, height;
 			Gdk.Pixbuf tmp = null;
 		       
 			image_view.GetSelection (out x, out y, out width, out height);
-			if (width > 0 && height > 0) 
-				icon_view.Selection.Clear ();
+//			if (width > 0 && height > 0) 
+//				icon_view.Selection.Clear ();
 				
 			if (image_view.Pixbuf != null) {
 				if (width > 0 && height > 0) {
 					tmp = new Gdk.Pixbuf (image_view.Pixbuf, x, y, width, height);
 					
-					preview_image.Pixbuf = PixbufUtils.TagIconFromPixbuf (tmp);
+					PreviewPixbuf = PixbufUtils.TagIconFromPixbuf (tmp);
 					
 					tmp.Dispose ();
 				} else {
-					preview_image.Pixbuf = PixbufUtils.TagIconFromPixbuf (image_view.Pixbuf);
+					PreviewPixbuf = PixbufUtils.TagIconFromPixbuf (image_view.Pixbuf);
 				}
 			}
 		}
@@ -364,49 +424,63 @@ public class TagCommands {
 		public void HandlePhotoChanged (FSpot.PhotoImageView sender)
 		{
 			int item = image_view.Item.Index;
-			photo_label.Text = String.Format (Mono.Posix.Catalog.GetString ("Photo {0} of {1}"), 
+			photo_label.Text = String.Format (Catalog.GetString ("Photo {0} of {1}"), 
 							  item + 1, query.Count);
 
 			photo_spin_button.Value = item + 1;
 		}
 
-		public void HandleIconViewSelectionChanged (FSpot.IBrowsableCollection collection) 
+		public void HandleIconSelectionChanged (object o, EventArgs args)
 		{
-			// FIXME this handler seems to be called twice for each selection change
-			if (icon_view.Selection.Count > 0)
-			{
-				FSpot.IBrowsableItem item = icon_view.Selection [0];
-				string path = item.DefaultVersionUri.LocalPath;
-				try {
-					preview_image.Pixbuf = new Gdk.Pixbuf (path);
-					image_view.UnsetSelection ();
-				} catch {
-					// FIXME add a real exception handler here.
-					System.Console.WriteLine ("Unable To Load image");
-				}
-			}
+			if (icon_view.SelectedItems.Length == 0)
+				return;
+
+			TreeIter iter;
+			icon_store.GetIter (out iter, icon_view.SelectedItems [0]); 
+			IconName = (string) icon_store.GetValue (iter, 0);
 		}
 
+		public bool FillIconView ()
+		{
+			icon_store.Clear ();
+			string [] icon_list = FSpot.Global.IconTheme.ListIcons ("Emblems");
+			foreach (string item_name in icon_list)
+				icon_store.AppendValues (item_name, GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, item_name, 32, (IconLookupFlags) 0));
+			return false;
+		}
+
+
 		public bool Execute (Tag t)
 		{
 			this.CreateDialog ("edit_icon_dialog");
 
-			this.Dialog.Title = String.Format (Mono.Posix.Catalog.GetString ("Edit Icon for Tag {0}"), t.Name);
+			this.Dialog.Title = String.Format (Catalog.GetString ("Edit Icon for Tag {0}"), t.Name);
 
-			preview_image.Pixbuf = t.Icon;
+			PreviewPixbuf = t.Icon;
 
 			query = new FSpot.PhotoQuery (db.Photos);
 			
 			if (db.Tags.Hidden != null)
-				query.Tags = new Tag [] { t, db.Tags.Hidden };
+				query.Terms = FSpot.OrTerm.FromTags (new Tag []{ t, db.Tags.Hidden });
 			else 
-				query.Tags = new Tag [] { t };
+				query.Terms = new FSpot.Literal (t);
 
 			image_view = new FSpot.PhotoImageView (query);
 			image_view.SelectionXyRatio = 1.0;
 			image_view.SelectionChanged += HandleSelectionChanged;
 			image_view.PhotoChanged += HandlePhotoChanged;
 
+                        external_photo_chooser = new Gtk.FileChooserButton (Catalog.GetString ("Select Photo from file"),
+                                                                 Gtk.FileChooserAction.Open);
+
+			external_photo_chooser.Filter = new FileFilter();
+			external_photo_chooser.Filter.AddPixbufFormats();
+                        external_photo_chooser.LocalOnly = false;
+                        external_photo_chooser_hbox.PackStart (external_photo_chooser);
+
+    			Dialog.ShowAll ();
+			external_photo_chooser.SelectionChanged += HandleExternalFileSelectionChanged;
+
 			photo_scrolled_window.Add (image_view);
 
 			if (query.Photos.Length > 0) {
@@ -418,45 +492,53 @@ public class TagCommands {
 				
 				image_view.Item.Index = 0;
 			} else {
-				photo_spin_button.Sensitive = false;
-				photo_spin_button.Value = 0.0;
+				from_photo_label.Markup = String.Format (Catalog.GetString (
+					"\n<b>From Photo</b>\n" +
+					" You can use one of your library photos as an icon for this tag.\n" +
+					" However, first you must have at least one photo associated\n" +
+					" with this tag. Please tag a photo as '{0}' and return here\n" +
+					" to use it as an icon."), t.Name); 
+				photo_scrolled_window.Visible = false;
+				photo_label.Visible = false;
+				photo_spin_button.Visible = false;
 			}			
-			
-			
-			// FIXME this path choosing method is completely wrong/broken/evil it needs to be
-			// based on real data but I want to get this release out.
-			string theme_dir = System.IO.Path.Combine (FSpot.Defines.GNOME_ICON_THEME_PREFIX,
-								   "share/icons/gnome/48x48/emblems");
-			if (System.IO.Directory.Exists (theme_dir))
-				icon_view = new IconView (new FSpot.DirectoryCollection (theme_dir));
-			else if (System.IO.Directory.Exists ("/opt/gnome/share/icons/gnome/48x48/emblems"))
-				icon_view = new IconView (new FSpot.DirectoryCollection ("/opt/gnome/share/icons/gnome/48x48/emblems"));
-			else if (System.IO.Directory.Exists ("/usr/share/icons/gnome/48x48/emblems"))
-				icon_view = new IconView (new FSpot.DirectoryCollection ("/usr/share/icons/gnome/48x48/emblems"));
-			else // This will just load an empty collection if the directory doesn't exist.
-				icon_view = new IconView (new FSpot.DirectoryCollection ("/usr/local/share/icons/gnome/48x48/emblems"));
+
+			icon_store = new ListStore (typeof (string), typeof (Gdk.Pixbuf));
+
+			icon_view = new Gtk.IconView (icon_store); 
+			icon_view.PixbufColumn = 1;
+			icon_view.SelectionMode = SelectionMode.Single;
+			icon_view.SelectionChanged += HandleIconSelectionChanged;
 
 			icon_scrolled_window.Add (icon_view);
-			icon_view.ThumbnailWidth = 32;
-			icon_view.DisplayTags = false;
-			icon_view.DisplayDates = false;
-			icon_view.Selection.Changed += HandleIconViewSelectionChanged;
+
 			icon_view.Show();
 
 			image_view.Show ();
 
+			FSpot.Delay fill_delay = new FSpot.Delay (FillIconView);
+			fill_delay.Start ();
+
 			ResponseType response = (ResponseType) this.Dialog.Run ();
 			bool success = false;
 
 			if (response == ResponseType.Ok) {
 				try {
-					t.Icon = preview_image.Pixbuf;
+					if (IconName != null) {
+						t.ThemeIconName = IconName;
+					} else {
+						t.ThemeIconName = null;
+						t.Icon = PreviewPixbuf;
+					}
 					//db.Tags.Commit (t);
 					success = true;
 				} catch (Exception ex) {
 					// FIXME error dialog.
 					Console.WriteLine ("error {0}", ex);
 				}
+			} else if (response == (ResponseType) (1)) {
+				t.Icon = null;
+				success = true;
 			}
 			
 			this.Dialog.Destroy ();
