@@ -33,8 +33,10 @@ using System.IO;
 using System;
 
 using Mono.Unix;
+using FSpot;
+using FSpot.UI.Dialog;
 
-public class TagSelectionWidget : TreeView {
+public class TagSelectionWidget : FSpot.Widgets.SaneTreeView {
 	TagSelectionWidget widget;
 	private TagStore tag_store;
 
@@ -47,6 +49,11 @@ public class TagSelectionWidget : TreeView {
 
 	// Selection management.
 
+	public Tag TagAtPosition (double x, double y) 
+    {
+        return TagAtPosition((int) x, (int) y);
+    }
+
 	public Tag TagAtPosition (int x, int y) 
 	{
 		TreePath path;
@@ -473,16 +480,6 @@ public class TagSelectionWidget : TreeView {
 		text_render.Editable = false;
 	}
 
-	// Override the default ButtonPressEvent because it is stupid and
-	// returns true, meaning if you want to have another handler for the ButtonPress
-	// event you have to Glib.ConnectBefore.  Plus you usually want the default one to
-	// run first so it will select/unselect anything necessary before popping up a menu, say.
-	protected override bool OnButtonPressEvent (Gdk.EventButton button)
-	{
-		base.OnButtonPressEvent (button);
-		return false;
-	}
-	
 	public void HandleTagNameEdited (object sender, EditedArgs args)
 	{
 		args.RetVal = false;
@@ -537,7 +534,6 @@ public class TagSelectionWidget : TreeView {
 		: base (new TreeStore (typeof(uint), typeof(string)))
 	{
 		HeadersVisible = false;
-		Selection.Mode = SelectionMode.Multiple;
 
 		complete_column = new TreeViewColumn ();
 				
