@@ -1,5 +1,6 @@
 using System;
 using Gtk;
+using FSpot;
 
 public class ThumbnailCommand {
 	
@@ -27,7 +28,9 @@ public class ThumbnailCommand {
 				break;
 
 			foreach (uint version_id in p.VersionIds) {
-				PhotoStore.GenerateThumbnail (p.GetVersionPath (version_id)).Dispose ();
+				Gdk.Pixbuf thumb = FSpot.ThumbnailGenerator.Create (p.VersionUri (version_id));
+				if (thumb !=  null)
+					thumb.Dispose ();
 			}
 			
 			count++;
