@@ -2,7 +2,8 @@ using System;
 using Gtk;
 using Gnome;
 using System.Collections;
-using Mono.Posix;
+using Mono.Unix;
+using FSpot.Widgets;
 
 namespace FSpot {
 	public class TimeChangedEventArgs : DbItemEventArgs {
@@ -12,6 +13,12 @@ namespace FSpot {
 		{
 			this.span = span;
 		}
+
+		public TimeSpan TimeSpan {
+			get {
+				return span;
+			}
+		}
 	}
 
 	public class TimeDialog : GladeDialog 
@@ -45,7 +52,7 @@ namespace FSpot {
 		
 		IBrowsableCollection collection;
 		BrowsablePointer Item;
-		IconView tray;
+		FSpot.Widgets.IconView tray;
 		PhotoImageView view;
 		Db db;
 		TimeSpan gnome_dateedit_sucks;
@@ -113,14 +120,7 @@ namespace FSpot {
 			if (! offset_entry.HasFocus)
 				offset_entry.Text = span.ToString ();
 
-			// The preceding text here is the second checkbutton in the Time dialog
-			// that says "Space all photos by []"
-#if false
-			starting_label.Text = String.Format (Catalog.GetString ("min. Starting at {0}"),
-							     EditTime);
-#else
 			starting_label.Text = "min.";
-#endif
 			difference_check.Label = String.Format (Catalog.GetString ("Shift all photos by {0}"),
 							      Offset);
 		}
@@ -133,7 +133,7 @@ namespace FSpot {
 			if (Item.IsValid) {
 				IBrowsableItem item = Item.Current;
 				
-				name_label.Text = item.Name;;
+				name_label.Text = System.Uri.UnescapeDataString(item.Name);
 				old_label.Text = item.Time.ToLocalTime ().ToString ();
 				
 				int i = collection.Count > 0 ? Item.Index + 1: 0;
@@ -223,7 +223,7 @@ namespace FSpot {
 				TimeSpan span = TimeSpan.Parse (offset_entry.Text);
 				if (span != current)
 					Offset = span;
-			} catch (System.Exception e) {
+			} catch (System.Exception) {
 				System.Console.WriteLine ("unparsable span {0}", offset_entry.Text);
 			}
 		}
@@ -265,7 +265,7 @@ namespace FSpot {
 		void HandleSelectionChanged (IBrowsableCollection sender)
 		{
 			if (sender.Count > 0) {
-				view.Item.Index = ((IconView.SelectionCollection)sender).Ids[0];
+				view.Item.Index = ((FSpot.Widgets.IconView.SelectionCollection)sender).Ids[0];
 
 			}
 		}
