@@ -1,6 +1,8 @@
 using Gtk;
+using GLib;
 using Gnome;
 using System;
+using System.Reflection;
 using System.IO;
 using System.Runtime.InteropServices;
 using System.Text;
@@ -10,14 +12,36 @@ using Mono.Unix;
 using Mono.Addins;
 using Mono.Addins.Setup;
 using FSpot.Utils;
+using FSpot.UI.Dialog;
 
 namespace FSpot 
 {
 public class Driver {
+	static void Version ()
+	{
+		Console.WriteLine (
+			"F-Spot  {0} - (c)2003-2008, Novell Inc" + Environment.NewLine +
+			"Personal photo management for the GNOME Desktop" + Environment.NewLine, 
+			FSpot.Defines.VERSION);
+	}
+
+	static void Versions ()
+	{
+	    Version ();
+            Console.WriteLine (".NET Version: " + Environment.Version.ToString());
+            Console.WriteLine (String.Format("{0}Assembly Version Information:", Environment.NewLine));
+            
+            foreach(Assembly asm in AppDomain.CurrentDomain.GetAssemblies()) {
+		    AssemblyName name = asm.GetName();
+                    Console.WriteLine ("\t" + name.Name + " (" + name.Version.ToString () + ")");
+		}	
+	}
+
 	static void Help ()
 	{
-		Console.WriteLine ("F-Spot  {0} - (c)2003-2008, Novell Inc" + Environment.NewLine +
-			"Personal photo management for the GNOME Desktop" + Environment.NewLine + Environment.NewLine +
+		Version ();
+		Console.WriteLine ();
+		Console.WriteLine (
 			"Usage: f-spot [options] " + Environment.NewLine +
 			"Options:" + Environment.NewLine +
 		  	"-b -basedir PARAM   path to the photo database folder" + Environment.NewLine +
@@ -27,7 +51,8 @@ public class Driver {
 			"-shutdown           shutdown a running f-spot instance" + Environment.NewLine +
 			"-slideshow          display a slideshow" + Environment.NewLine +
 			"-V -version         Display version and licensing information" + Environment.NewLine +
-			"-v -view            view file(s) or directory(ies)" +Environment.NewLine, FSpot.Defines.VERSION);
+			"-versions           Display version and dependencies informations" + Environment.NewLine +
+			"-v -view            view file(s) or directory(ies)");
 	}
 
 	static int Main (string [] args)
@@ -44,6 +69,10 @@ public class Driver {
 		bool slideshow = false;
 		string import_uri = null;
 		
+		// Debug GdkPixbuf critical warnings
+		//LogFunc logFunc = new GLib.LogFunc (GLib.Log.PrintTraceLogFunction);
+		//Log.SetLogHandler ("GdkPixbuf", GLib.LogLevelFlags.Critical, logFunc);
+
 		FSpot.Global.PhotoDirectory = (string) Preferences.Get(Preferences.STORAGE_PATH);
 
 		for (int i = 0; i < args.Length && !shutdown; i++) {
@@ -83,7 +112,7 @@ public class Driver {
 				import_uri = args [++i];
 				break;
 			
-			case "-slideshow":
+			case "-slideshow": case "--slideshow":
 				slideshow = true;
 				break;
 
@@ -99,8 +128,16 @@ public class Driver {
 				view = true;
 				uris.Add (args [++i]);
 				break;
+
+			case "-versions": case "--versions":
+				Versions ();
+				return 0;
 			
-			case "--debug": case "--trace": case "--profile": case "--uninstalled":
+			case "-V": case "-version": case "--version":
+				Version ();
+				return 0;
+			
+			case "--debug": case "--trace": case "--profile": case "--uninstalled": case "--gdb":
 				break;
 
 			default:
@@ -149,7 +186,13 @@ public class Driver {
 			AddinManager.Initialize (FSpot.Global.BaseDirectory);
 			AddinManager.Registry.Update (null);
 			SetupService setupService = new SetupService (AddinManager.Registry);
-			setupService.Repositories.RegisterRepository (null, "http://addins.f-spot.org/" + Defines.VERSION, false);
+			string maj_version = String.Join (".", Defines.VERSION.Split ('.'), 0, 3);
+			foreach (AddinRepository repo in setupService.Repositories.GetRepositories ())
+				if (repo.Url.StartsWith ("http://addins.f-spot.org/") && !repo.Url.StartsWith ("http://addins.f-spot.org/" + maj_version)) {
+					Console.WriteLine ("Unregistering {0}", repo.Url);
+					setupService.Repositories.RemoveRepository (repo.Url);
+				}
+			setupService.Repositories.RegisterRepository (null, "http://addins.f-spot.org/" + maj_version, false);
 
 			bool create = true;
 			int retry_count = 0;
